==> haskell-persistent-postgresql-2.13.4.1-14.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-Hn73XA10edCIOgFmt3RUGU
key:                  persistent-postgresql-2.13.4.1-Hn73XA10edCIOgFmt3RUGU
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  8f172f650ca9566b210498163661e885
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-Hn73XA10edCIOgFmt3RUGU
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s containers-0.6.5.1
    monad-logger-0.3.40-LHJ6PMq0aC62c6JpmSN96y mtl-2.2.2
    persistent-2.14.5.1-9xnFRv8rkde2AoeFkZgfdg
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    postgresql-simple-0.6.5-JwKcyydaL1OCM2FFIZS5oD
    resource-pool-0.2.3.2-GoxnmSc4Q995sKTSDuBd5z
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM
    string-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vault-0.3.1.5-KGmCdA93rcM4DaC6kTp3wh

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.4.1-37-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-IfUKbTMpCEYCc7JM11gp0a
key:                  persistent-postgresql-2.13.4.1-IfUKbTMpCEYCc7JM11gp0a
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  5737a91ecbfcb9297ac724a35d4e7930
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-IfUKbTMpCEYCc7JM11gp0a
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x containers-0.6.5.1
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa mtl-2.2.2
    persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    postgresql-simple-0.6.5-4zlRYx9pxaFIsS1fS8BtsQ
    resource-pool-0.2.3.2-2ghaoAEpV2r22WQ70y4rca
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    string-conversions-0.4.0.1-DIhGmAxRazx6IKbU2apUQz text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
